searchData={"items":[{"type":"module","title":"Hemdal","doc":"Hemdal is a system for Alert/Alarm very customizable. It's based on\n[Nagios](https://www.nagios.com) where you have different scripts to check\nthe status of different elements of your system providing back information\nabout these checks.\n\nThe Hemdal Core is agnostic to the way we can be\nconnected to the external server to perform checks and even, we can\nimplement our own agents in case the access or communication to the servers\nis difficult or requires customization.","ref":"Hemdal.html"},{"type":"module","title":"Motivation - Hemdal","doc":"The problem with other systems like Nagios, Icinga or Sensu is they are\nbased on the client/server infrastructure and requires to install an agent\ninside of each remote node. Hemdal is agnostic about the way of access to\nthe host but it's more inclined to provide the mechanics needed to connect\nactively without agents. However, it's agnostic, it's meaning that we could\nimplement an agent and access to the server using that agent.\n\n## Hosts\n\nThe way to run the checks depends on the host. By default, `hemdal_core` is\nonly implementing `Local` which is running locally the commands using the\nsame user as the hemdal core. The available and official hosts are the\nfollowing ones:\n\n- `Local`, included with core.\n- [`Trooper`](https://github.com/altenwald/hemdal_trooper) uses\n  [Trooper](https://github.com/army-cat/trooper) to connect via SSH to the\n  remote servers.\n\nSee `Hemdal.Config` for further information.","ref":"Hemdal.html#module-motivation"},{"type":"module","title":"Config - Hemdal","doc":"The configuration is also abstracted using `Hemdal.Config`. We can use only\none provider and this should be configured as follows:\n\n```elixir\n# config/config.exs\nconfig :hemdal, :config_module, Hemdal.Config.Backend.Env\n\nconfig :hemdal, Hemdal.Config, [\n  # here the checks configuration\n]\n```\n\nWe have available the following official backends for the configuration:\n\n- `Hemdal.Config.Backend.Env`, as shown above, it's putting the whole\n  configuration inside of the configuration file for Elixir.\n- `Hemdal.Config.Backend.Json`, it's specifying the JSON files to be\n  loaded and they are loaded each time we are requesting data for the\n  alerts.\n\nSee `Hemdal.Config` for further information.","ref":"Hemdal.html#module-config"},{"type":"module","title":"Event - Hemdal","doc":"When something is happening with the checks an event is generated. There\nare different ways to configure the way we receive the events and it's\nlinked to the checks, see `Hemdal.Check` for further information.\n\nThe events could be implemented via `GenStage`. See `Hemdal.Event` for\nfurther information.","ref":"Hemdal.html#module-event"},{"type":"module","title":"Notification - Hemdal","doc":"One of the event consumers is in charge of triggering notifications. These\nhave a specific format. We have implementation at the moment for the\nfollowing backends for the notifications:\n\n- `Hemdal.Notifier.Slack` is sending the event to a Slack webhook.\n- `Hemdal.Notifier.Mattermost` is sending the even to a Mattermost webhook.\n\nSee `Hemdal.Notifier` for further information.","ref":"Hemdal.html#module-notification"},{"type":"function","title":"Hemdal.get_all_alerts/0","doc":"Retrieve all the alerts. See `Hemdal.Check.get_all/0` for further\ninformation.","ref":"Hemdal.html#get_all_alerts/0"},{"type":"function","title":"Hemdal.reload_all/0","doc":"Reload all of the alerts and hosts. See `Hemdal.Check.reload_all/0` and\n`Hemdal.Host.reload_all/0` for further information.","ref":"Hemdal.html#reload_all/0"},{"type":"function","title":"Hemdal.start_alert!/1","doc":"Start the alert based on the alert ID.","ref":"Hemdal.html#start_alert!/1"},{"type":"module","title":"Hemdal.Check","doc":"Every check performed by Hemdal is based on a state machine which is in\ncharge of running a command, check the return and based on the return and\nif it was successfully executed or not, determine the state of the machine.\n\nThe state machine has the following states:\n\n- `disabled`: it's not performing checks, it waits until it's activated.\n- `normal`: it's running correctly the command and always receiving a\n  success state. It's configuring a state timeout based on `check_in_sec`\n  from `Hemdal.Config.Alert`.\n- `failing`: when in `normal` state, it receives an failed response, it's\n  moved to `failing` status. It's configuring a state timeout based on\n  `recheck_in_sec` and if it's not recovering after a number of\n  `retries` it's moving to `broken` (see `Hemdal.Config.Alert`).\n- `broken`: it was not running correctly for some time. We consider the\n  subject under check broken and we are checking every\n  `broken_recheck_in_sec` seconds. Only if it's recovered it back to\n  `normal` state.","ref":"Hemdal.Check.html"},{"type":"type","title":"Hemdal.Check.alert_id/0","doc":"The alert ID in use to identify the state machine running the checks for the alert.","ref":"Hemdal.Check.html#t:alert_id/0"},{"type":"function","title":"Hemdal.Check.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hemdal.Check.html#child_spec/1"},{"type":"function","title":"Hemdal.Check.exists?/1","doc":"Check if the alert is running.","ref":"Hemdal.Check.html#exists?/1"},{"type":"function","title":"Hemdal.Check.get_all/0","doc":"Get all of the alerts running. It's requesting to the supervisor the list\nof all of the alerts and it's gathering the status for each one based on\nthe `get_status/1` function.","ref":"Hemdal.Check.html#get_all/0"},{"type":"function","title":"Hemdal.Check.get_pid/1","doc":"Returns the PID of the alert process if it's running.","ref":"Hemdal.Check.html#get_pid/1"},{"type":"function","title":"Hemdal.Check.get_status/1","doc":"Get the status of an alert. It's requesting the status directly to the\nprocess.","ref":"Hemdal.Check.html#get_status/1"},{"type":"function","title":"Hemdal.Check.reload_all/0","doc":"Reload all of the alerts based on the configuration backend. See\n`Hemdal.Config` for further information. If the alert isn't running\nit's starting it.","ref":"Hemdal.Check.html#reload_all/0"},{"type":"type","title":"Hemdal.Check.returned_status/0","doc":"The returned status retrieved from the process is built to contain a map with\nkeys which are strings and the content which could be different depending\non the key. The keys are the following ones:\n\n- `status` is an atom and it could be `:ok`, `:disabled`, `:warn` or\n  `:error`.\n- `alert` is a map which is including information for the alert itself,\n  information like: id, name, host, and command.\n- `last_update` is a naive datetime generated at the moment.\n- `result` is a map with information of the executed command.","ref":"Hemdal.Check.html#t:returned_status/0"},{"type":"function","title":"Hemdal.Check.start_all/0","doc":"Ensure all of the alerts are started.","ref":"Hemdal.Check.html#start_all/0"},{"type":"type","title":"Hemdal.Check.status/0","doc":"The status available inside of the events. It's valid for both,\ncurrent and previous state.","ref":"Hemdal.Check.html#t:status/0"},{"type":"type","title":"Hemdal.Check.t/0","doc":"","ref":"Hemdal.Check.html#t:t/0"},{"type":"function","title":"Hemdal.Check.update_alert/1","doc":"Update the alert passing the new configuration to the process. It's\nuseful when we want to change the configuration for the command, the\nhost or whatever else inside of the alert/check.","ref":"Hemdal.Check.html#update_alert/1"},{"type":"behaviour","title":"Hemdal.Config","doc":"Hemdal needs to load a configuration to get the checks to be processed,\nhow to trigger the alerts and how to connect to the systems to perform\nthe checks.\n\nThis module define all of the data needed for the configuration and the\ncontract needed to be followed for the libraries which are going to act\nas backend systems.\n\nThe backend is configured in the following way:\n\n```elixir\n# config/config.exs\nconfig :hemdal, config_module: Hemdal.Config.Backend.Env\n```\n\nThe possible backends and supported officially are:\n\n- `Hemdal.Config.Backend.Env` which is configuring via `config.exs` in\n  the Elixir configuration way.\n- `Hemdal.Config.Backend.Json` which is using JSON files.\n\nCheck those modules to get further information about the implementation\nand usage.","ref":"Hemdal.Config.html"},{"type":"function","title":"Hemdal.Config.get_alert_by_id!/1","doc":"Retrieves the alert giving an `alert_id` using the configured backend.","ref":"Hemdal.Config.html#get_alert_by_id!/1"},{"type":"callback","title":"Hemdal.Config.get_alert_by_id!/1","doc":"Retrieve an alert giving an `alert_id`.","ref":"Hemdal.Config.html#c:get_alert_by_id!/1"},{"type":"function","title":"Hemdal.Config.get_all_alerts/0","doc":"Retrieve all of the alerts using the configured backend.","ref":"Hemdal.Config.html#get_all_alerts/0"},{"type":"callback","title":"Hemdal.Config.get_all_alerts/0","doc":"Get all of the alerts. It should provide a way to retrieve a list with\nthe alerts in the format defined by `Hemdal.Config.Alert` or an empty\nlist.","ref":"Hemdal.Config.html#c:get_all_alerts/0"},{"type":"function","title":"Hemdal.Config.get_all_hosts/0","doc":"Retrieve all of the hosts using the configured backend.","ref":"Hemdal.Config.html#get_all_hosts/0"},{"type":"callback","title":"Hemdal.Config.get_all_hosts/0","doc":"Retrieve all of the hosts. The implementation of this callback should\nprovide a list of `Hemdal.Config.Host` or an empty list.","ref":"Hemdal.Config.html#c:get_all_hosts/0"},{"type":"function","title":"Hemdal.Config.get_host_by_id!/1","doc":"Retrieve the host giving a `host_id` using the configured backend.","ref":"Hemdal.Config.html#get_host_by_id!/1"},{"type":"callback","title":"Hemdal.Config.get_host_by_id!/1","doc":"Retrieve the host giving a `host_id`.","ref":"Hemdal.Config.html#c:get_host_by_id!/1"},{"type":"module","title":"Hemdal.Config.Alert","doc":"Alert entity used for the alert configuration. It is including the following\nconfiguration params:\n\n- `id` the ID for the alert. Used for launching the process,\n  see `Hemdal.Check`.\n- `enabled` let us know if the alert is enabled (ok, warn, or error) or\n  disabled (in disabled status).\n- `name` the name provided to the alert.\n- `check_in_sec` the interval time (in seconds) to run the check. In `ok` or\n  `normal` state.\n- `recheck_in_sec` the interval time (in seconds) where the command is\n  failing and it should be checked a number of `retries` in this interval of\n  time previously to move to `broken` state.\n- `broken_recheck_in_sec` the interval time (in seconds) where the command is\n  running during the `broken` state.\n- `retries` is the number of retries we are running in `failing` state\n  previously to determine it's broken.\n- `command_args` is a list of arguments to be in use with the command.\n- `host` is the `Hemdal.Config.Host` data.\n- `command` is a nested structure including the command to be executed,\n  the name of the command, and the command type. See\n  `Hemdal.Config.Alert.Command`.\n- `notifiers` is a list of `Hemdal.Config.Notifier`.","ref":"Hemdal.Config.Alert.html"},{"type":"function","title":"Hemdal.Config.Alert.cast/2","doc":"","ref":"Hemdal.Config.Alert.html#cast/2"},{"type":"function","title":"Hemdal.Config.Alert.make/2","doc":"","ref":"Hemdal.Config.Alert.html#make/2"},{"type":"function","title":"Hemdal.Config.Alert.make!/2","doc":"","ref":"Hemdal.Config.Alert.html#make!/2"},{"type":"type","title":"Hemdal.Config.Alert.t/0","doc":"","ref":"Hemdal.Config.Alert.html#t:t/0"},{"type":"module","title":"Hemdal.Config.Alert.Command","doc":"The command structure is defining the command to be executed inside of\neach alert. The data used is:\n\n- `name` the name of the script.\n- `type` the type of the script could be `line`, `script` or\n  `interactive`. The first one let us define a command in a single line,\n  the last one let us define a script, a multi-line code which will be\n  copied and executed in the host, and the last one let us run a command\n  interacting with a process for providing information in runtime.\n- `command` as the command line to be executed. It could be only one line\n  or a multi-line script.","ref":"Hemdal.Config.Alert.Command.html"},{"type":"function","title":"Hemdal.Config.Alert.Command.cast/2","doc":"","ref":"Hemdal.Config.Alert.Command.html#cast/2"},{"type":"function","title":"Hemdal.Config.Alert.Command.make/2","doc":"","ref":"Hemdal.Config.Alert.Command.html#make/2"},{"type":"function","title":"Hemdal.Config.Alert.Command.make!/2","doc":"","ref":"Hemdal.Config.Alert.Command.html#make!/2"},{"type":"type","title":"Hemdal.Config.Alert.Command.t/0","doc":"","ref":"Hemdal.Config.Alert.Command.html#t:t/0"},{"type":"module","title":"Hemdal.Config.Host","doc":"The host information.","ref":"Hemdal.Config.Host.html"},{"type":"function","title":"Hemdal.Config.Host.cast/2","doc":"","ref":"Hemdal.Config.Host.html#cast/2"},{"type":"function","title":"Hemdal.Config.Host.make/2","doc":"","ref":"Hemdal.Config.Host.html#make/2"},{"type":"function","title":"Hemdal.Config.Host.make!/2","doc":"","ref":"Hemdal.Config.Host.html#make!/2"},{"type":"type","title":"Hemdal.Config.Host.t/0","doc":"","ref":"Hemdal.Config.Host.html#t:t/0"},{"type":"module","title":"Hemdal.Config.Module","doc":"Defines the type for module in use for the `Hemdal.Config.Notifier` and\n`Hemdal.Host` implementations to define which modules will be in use for\neach case.","ref":"Hemdal.Config.Module.html"},{"type":"type","title":"Hemdal.Config.Module.t/0","doc":"Module is `module()`.","ref":"Hemdal.Config.Module.html#t:t/0"},{"type":"module","title":"Hemdal.Config.Notifier","doc":"Notifier is in charge of define the amount of notifiers it should be\nin use for a notification, and the data to perform the notification.\n\nThe available fields are the following ones:\n\n- `token` is the information needed to send a message for some\n  platforms like Slack or Mattermost. But it could means even a\n  password for an email backend.\n- `type` the name used to be concatenated to `Hemdal.Notifier` and\n  find for the module.\n- `username` is the name of the user to show the notification. But\n  it could means different things depending on the backend. For an\n  email backend it could be the user/email to send the message.\n- `log_level` used to send the notifications. If we specify an\n  `error` log level it will notify only when a change from/to error\n  is happening. See `Hemdal.Event.Notification` for further\n  information.\n- `metadata` the extra data sent to the notifier.","ref":"Hemdal.Config.Notifier.html"},{"type":"function","title":"Hemdal.Config.Notifier.cast/2","doc":"","ref":"Hemdal.Config.Notifier.html#cast/2"},{"type":"function","title":"Hemdal.Config.Notifier.make/2","doc":"","ref":"Hemdal.Config.Notifier.html#make/2"},{"type":"function","title":"Hemdal.Config.Notifier.make!/2","doc":"","ref":"Hemdal.Config.Notifier.html#make!/2"},{"type":"type","title":"Hemdal.Config.Notifier.t/0","doc":"","ref":"Hemdal.Config.Notifier.html#t:t/0"},{"type":"module","title":"Hemdal.Config.Options","doc":"Define the options (`Keyword`) implementation for `Construct`. This way we\ncan use the `Hemdal.Config.Options` everywhere the `options` entry is\nneeded.","ref":"Hemdal.Config.Options.html"},{"type":"type","title":"Hemdal.Config.Options.t/0","doc":"Options is `Keyword.t()` or `map()`.","ref":"Hemdal.Config.Options.html#t:t/0"},{"type":"module","title":"Hemdal.Config.Backend.Env","doc":"Configuration backend reader using the environment or Elixir configuration.\nSee `Hemdal.Config.Backend` for further information.\n\nThe backend is needing the configuration (see `Application` or `Config`)\nfor specify the configuration as follows:\n\n```elixir\n# config/config.exs\nimport Config\n\nconfig :hemdal, Hemdal.Config, [\n  [\n    id: \"36c16e85-7221-4021-8d6d-89f38a6d136c\",\n    name: \"valid alert check\",\n    enabled: true,\n    host: [\n      id: \"ec8fff22-41c2-4245-8a7b-5157d40c33a7\",\n      module: Hemdal.Host.Local,\n      name: \"localhost\"\n    ],\n    command: [\n      name: \"get ok status\",\n      type: \"line\",\n      command: \"echo '[\"OK\", \"valid one!\"]'\"\n    ],\n    check_in_sec: 60,\n    recheck_in_sec: 1,\n    broken_recheck_in_sec: 10,\n    retries: 1\n  ]\n]\n```\n\nSee `Hemdal.Config.Alert` and `Hemdal.Config.Host` for further information.","ref":"Hemdal.Config.Backend.Env.html"},{"type":"function","title":"Hemdal.Config.Backend.Env.get_all_alerts/0","doc":"Retrieve the full list of the alerts which appear in the environment\nconfiguration.","ref":"Hemdal.Config.Backend.Env.html#get_all_alerts/0"},{"type":"function","title":"Hemdal.Config.Backend.Env.get_all_hosts/0","doc":"Retrieve the full list of the hosts which appear in the environment\nconfiguration.","ref":"Hemdal.Config.Backend.Env.html#get_all_hosts/0"},{"type":"module","title":"Hemdal.Config.Backend.Json","doc":"Configuration backend reader using JSON. See `Hemdal.Config.Backend` for\nfurther information.\n\nThe backend is needing the configuration (see `Application` or `Config`)\nto know where the JSON file is located. You can write in the configuration\nan entry like this:\n\n```elixir\n# config/config.exs\nimport Config\n\nconfig :hemdal, Hemdal.Config,\n  hosts_file: \"hosts.json\",\n  alerts_file: \"alerts.json\"\n```\n\nThe hosts file is intended to configure all of the necessary hosts to be\naccessible to run the checks and the alerts are the configuration for each\ncheck.\n\nAn example of the hosts file is as follows:\n\n```json\n[\n  {\n    \"id\": \"2a8572d4-ceb3-4200-8b29-dd1f21b50e54\",\n    \"name\": \"localhost\",\n    \"module\": \"Hemdal.Host.Local\",\n    \"max_workers\": 1\n  }\n]\n```\n\nAnd an example for the alerts file is as follows:\n\n```json\n[\n  {\n    \"id\": \"52d13d6d-f217-4152-965d-cf5f488ceac4\",\n    \"name\": \"valid alert check\",\n    \"host_id\": \"2a8572d4-ceb3-4200-8b29-dd1f21b50e54\",\n    \"command\": {\n      \"name\": \"get ok status\",\n      \"type\": \"line\",\n      \"command\": \"echo '[\"OK\", \"valid one!\"]'\"\n    }\n  }\n]\n```\n\nIf you want to know more about what are the parameters you can use,\nsee `Hemdal.Config.Alert` and `Hemdal.Config.Host` for further information.","ref":"Hemdal.Config.Backend.Json.html"},{"type":"function","title":"Hemdal.Config.Backend.Json.get_all_alerts/0","doc":"Get all of the alerts. It's reading the alerts file specified in the\nconfiguration and the hosts file to create the full information for\nthe alert.","ref":"Hemdal.Config.Backend.Json.html#get_all_alerts/0"},{"type":"function","title":"Hemdal.Config.Backend.Json.get_all_hosts/0","doc":"Get all of the hosts. It's reading the hosts file specified in the\nconfiguration and returning it as a list of `Hemdal.Config.Host`\nelements.","ref":"Hemdal.Config.Backend.Json.html#get_all_hosts/0"},{"type":"behaviour","title":"Hemdal.Host","doc":"Host is spawning processes to run tasks for the corresponding host. It's\na way of limiting the amount of commands triggered against a host and\nensure the rest of the commands stay in the queue.\n\nIt's also the base for the implementation of the way of running commands.\nAt the moment the available way to run commands are:\n\n- `Hemdal.Host.Local` intended to run local commands.\n- `Hemdal.Host.Trooper` intended to run SSH commands. It's not included\n  in the main repository, you can find more information\n  [here](https://github.com/altenwald/hemdal_trooper).\n\nIf you want to know more about what could be included in a command or\nto be run in a host you can review the following modules:\n\n- `Hemdal.Config.Alert.Command` where you can check what's included\n  inside of the command.\n- `Hemdal.Config.Host` where you can find information about the host.","ref":"Hemdal.Host.html"},{"type":"behaviour","title":"Implement a new Host - Hemdal.Host","doc":"If you need to implement a new way to run external commands, you can\ncreate a new `Hemdal.Host.XXX` module which will be using the module\n`Hemdal.Host` inside. For example, if you need to implement a telnet\nway to access to the remote hosts, you can implement a module as follows:\n\n```elixir\ndefmodule Hemdal.Host.Telnet do\n  use Hemdal.Host\n\n  @impl Hemdal.Host\n  def exec(host, command) do\n    # do your stuff\n    {:ok, errorlevel, output}\n  end\n\n  @impl Hemdal.Host\n  def write_file(host, filename, content) do\n    raise \"Impossible to transfer files\"\n  end\n\n  @impl Hemdal.Host\n  def delete(host, filename) do\n    raise \"Impossible to remove files\"\n  end\nend\n```\n\nWhile telnet isn't prepared to transfer files, it's raising an error\nwhich is telling the system that's impossible to use the script way\nfor running commands.","ref":"Hemdal.Host.html#module-implement-a-new-host"},{"type":"function","title":"Hemdal.Host.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Hemdal.Host.html#child_spec/1"},{"type":"type","title":"Hemdal.Host.command/0","doc":"The command to be executed.","ref":"Hemdal.Host.html#t:command/0"},{"type":"type","title":"Hemdal.Host.command_args/0","doc":"The command arguments to be passed with the execution command.","ref":"Hemdal.Host.html#t:command_args/0"},{"type":"callback","title":"Hemdal.Host.delete/2","doc":"Remove a file which was created with `write_file/3` when the execution of\nthe script was finalized.","ref":"Hemdal.Host.html#c:delete/2"},{"type":"type","title":"Hemdal.Host.errorlevel/0","doc":"The errorlevel is shell concept. In the shell every command is returning\nan integer as the errorlevel after the running, if that's 0 (zero), it's\nmeaning the execution was fine, otherwise a positive or negative number\nmeans the running was wrong and the number could means something different\ndepending on the command.","ref":"Hemdal.Host.html#t:errorlevel/0"},{"type":"callback","title":"Hemdal.Host.exec/2","doc":"Exec a command using the method implemented by the module where it's\nimplemented. The `c:exec/2` command is getting a handler from the transaction\nand the command to be executed as a string.","ref":"Hemdal.Host.html#c:exec/2"},{"type":"function","title":"Hemdal.Host.exec/3","doc":"Run or execute the command passed as parameter. It's needed to pass the host ID\nto find the process where to send the request, and the the command and the\narguments to run the command.\n\nIt's returning a tuple for `:ok` or `:error` and a set of data which depends on\nif it was success or not.\n\nThe success return data is usually including the following keys (all of them as\nstrings):\n\n- `status` which could be `OK`, `FAIL`, `WARN` or `UNKNOWN`.\n- `message` which is a string containing a message to show.\n\nThe failure return data is usually similar to the previous one but it could be\ncontaining something different depending on the return of the remote command.\nIf the JSON sent back from the command is valid, it's usually using that as\ndata and it's marked as `UNKNOWN` status if there is no status defined.","ref":"Hemdal.Host.html#exec/3"},{"type":"callback","title":"Hemdal.Host.exec_interactive/3","doc":"Exec an interactive command implemented by the module where it's\nimplemented. The `c:exec_interactive/3` command is getting a handler from the\ntransaction and the command to be executed as a string.","ref":"Hemdal.Host.html#c:exec_interactive/3"},{"type":"function","title":"Hemdal.Host.exists?/1","doc":"Check if the host is started based on the host ID passed as parameter.","ref":"Hemdal.Host.html#exists?/1"},{"type":"function","title":"Hemdal.Host.get_all/0","doc":"Get all the host IDs that are running at the moment of calling this function.","ref":"Hemdal.Host.html#get_all/0"},{"type":"function","title":"Hemdal.Host.get_pid/1","doc":"Retrieve the PID providing the host ID.","ref":"Hemdal.Host.html#get_pid/1"},{"type":"type","title":"Hemdal.Host.handler/0","doc":"Handler is used by the backend implementation of the host, it could be\nwhatever depending on the needs of the backend implementation. For\nexample, it could be the SSH connection or the credentials, or the way\nto access to the PTY or TTY. See the implementations for further details.","ref":"Hemdal.Host.html#t:handler/0"},{"type":"type","title":"Hemdal.Host.output/0","doc":"The console output. It will be decoded using JSON to determine what's the\ninformation processed and generated by the command to be processed.","ref":"Hemdal.Host.html#t:output/0"},{"type":"type","title":"Hemdal.Host.reason/0","doc":"The reason of the failure. It's usually an atom, but it could be whatever.","ref":"Hemdal.Host.html#t:reason/0"},{"type":"function","title":"Hemdal.Host.reload_all/0","doc":"Performs a reload for all of the hosts. It's retrieving the configuration for\nall of the hosts and applying it for each host. It's reloading the\nconfiguration for each host and applying it through the `update_host/1`\nfunction.","ref":"Hemdal.Host.html#reload_all/0"},{"type":"function","title":"Hemdal.Host.start/1","doc":"Start a new host under the `Hemdal.Host.Supervisor` module.","ref":"Hemdal.Host.html#start/1"},{"type":"function","title":"Hemdal.Host.start_all/0","doc":"Start all of the hosts based on the configuration. It's retrieving all of\nthe hosts from the configuration and the using each host with the `start/1`\nfunction.","ref":"Hemdal.Host.html#start_all/0"},{"type":"function","title":"Hemdal.Host.start_link/1","doc":"Start a new host directly. It's intended to be in use from the supervisor,\nbut it could be used for test purposes.","ref":"Hemdal.Host.html#start_link/1"},{"type":"function","title":"Hemdal.Host.stop/1","doc":"Terminate the processes related to a process ID.","ref":"Hemdal.Host.html#stop/1"},{"type":"type","title":"Hemdal.Host.t/0","doc":"","ref":"Hemdal.Host.html#t:t/0"},{"type":"callback","title":"Hemdal.Host.transaction/2","doc":"The transaction is an optional callback which is implemented by default if\nyou are using `use Hemdal.Host` and it's ensuring you can provide to the\n`write_file/3`, `exec/2` and `delete/2` the same handler which must be\nprovided to the running function. As an example, the default implementation\nof this callback is as follows:\n\n```elixir\n@impl Hemdal.Host\ndef transaction(host, f), do: f.(host)\n```","ref":"Hemdal.Host.html#c:transaction/2"},{"type":"function","title":"Hemdal.Host.update_host/1","doc":"Update the host configuration. If the host isn't running it's starting it\nand passing it the configuration provided as the `host` parameter. In a\nnutshell, it's: if exist host ID then perform an update of the host\ninformation, else start the process with the host information.","ref":"Hemdal.Host.html#update_host/1"},{"type":"callback","title":"Hemdal.Host.write_file/3","doc":"Write a file in the remote (or local) host. It's intended to write the\nscripts which will be needed to be executed after that with `exec/2`.","ref":"Hemdal.Host.html#c:write_file/3"},{"type":"module","title":"Hemdal.Host.Local","doc":"Implement the host access for the local running commands.\nIt is intended to run commands locally where the system is.\n\nIt's not recommended when we are going to put the running\nsystem inside of a container because it's very limited.","ref":"Hemdal.Host.Local.html"},{"type":"function","title":"Hemdal.Host.Local.delete/2","doc":"Remove the temporal file.","ref":"Hemdal.Host.Local.html#delete/2"},{"type":"function","title":"Hemdal.Host.Local.exec/2","doc":"Run locally a command. It's using `System.shell/2` for achieving that.","ref":"Hemdal.Host.Local.html#exec/2"},{"type":"function","title":"Hemdal.Host.Local.write_file/3","doc":"Write a file locally, the file is intended to be located in a temporal\nlocation, if the file exists previously it will fail ensuring it's not\noverloading existent files.","ref":"Hemdal.Host.Local.html#write_file/3"},{"type":"module","title":"Hemdal.Event","doc":"Generate events to be consumed. It's the producer for the events.","ref":"Hemdal.Event.html"},{"type":"function","title":"Hemdal.Event.notify/1","doc":"","ref":"Hemdal.Event.html#notify/1"},{"type":"type","title":"Hemdal.Event.t/0","doc":"The event is generated usually in `Hemdal.Check` module and it's\nbased on the structure:\n\n- `alert` based on `Hemdal.Config.Alert`\n- `status` which is the current status to notify\n- `prev_status` which is the previous status\n- `fail_started` when the fail started to happens\n- `fail_duration` how long the fail is/was\n- `last_update` when the event was created\n- `metadata` more information for the event","ref":"Hemdal.Event.html#t:t/0"},{"type":"module","title":"Hemdal.Event.Log","doc":"Consume each event from `Hemdal.Event` and process it to generate a log\nvia `Logger`.","ref":"Hemdal.Event.Log.html"},{"type":"module","title":"Hemdal.Event.Mock","doc":"Consume the events generated by the system and send all of these events\nto the process which run `start_link/0`. The even is `Hemdal.Event.t()`.","ref":"Hemdal.Event.Mock.html"},{"type":"function","title":"Hemdal.Event.Mock.start_link/0","doc":"It is starting a consumer, linked to the caller process, and sending\nall of the events to the caller process.","ref":"Hemdal.Event.Mock.html#start_link/0"},{"type":"function","title":"Hemdal.Event.Mock.stop/1","doc":"Stop the consumer, while it's linked to the caller process it's a good\nidea to stop it.","ref":"Hemdal.Event.Mock.html#stop/1"},{"type":"module","title":"Hemdal.Event.Notification","doc":"Consume events from `Hemdal.Event` to generate the notifications\nvia `Hemdal.Notifier`. It's based on the configuration from the\n`Hemdal.Config.Notifier` module and based on the configuration\nfor the `log_level` and the level of the event, it could be\nreported or not.\n\nThe log levels could be:\n\n- `debug` it's reporting everything to the notifier.\n- `warn` notifies if the previous status is different from\n  the new one.\n- `error` notifies only if the change is from/to error status.","ref":"Hemdal.Event.Notification.html"},{"type":"function","title":"Hemdal.Event.Notification.process_event/2","doc":"","ref":"Hemdal.Event.Notification.html#process_event/2"},{"type":"behaviour","title":"Hemdal.Notifier","doc":"Notifier implements the base for a notification system which will send\nthe event or information message to an external service like Slack,\nMattermost, Mailgun, Sendblue, or whatever else provider.\n\nThe notifier implementation must define the `send/3` callback ensuring\nthe sending of the information is being able. The official notifiers\nsupported and implemented by Hemdal are:\n\n- `Hemdal.Notifier.Slack` which implements the sending of the Slack\n  message avoiding implement the optional callbacks.\n- `Hemdal.Notifier.Mattermost` which implements the sending of the\n  Mattermost message and in the same way avoid implement the optional\n  callbacks because are compatible with Slack.\n- `Hemdal.Notifier.Mock` is an implementation which makes easier the\n  implementation of tests.","ref":"Hemdal.Notifier.html"},{"type":"behaviour","title":"Implement a new Notifier - Hemdal.Notifier","doc":"The requirements are not too many, you only need to create a module\nin your project with the name `Hemdal.Notifier.XXX` changing the `XXX`\nwith the name you want to implement. For example, if you have a\nspecific system via TCP created to notify in your installation, if\nyou give to that system the name of _mercury_, you can create a module\nin the implementation of the alert system called `Hemdal.Notifier.Mercury`\nand then:\n\n```elixir\ndefmodule Hemdal.Notifier.Mercury do\n  use Hemdal.Notifier\n\n  @impl Hemdal.Notifier\n  def send(message, token, metadata) do\n    # do your stuff\n  end\nend\n```\n\nThe return of `send/3` isn't going to be in use, you can return whatever.","ref":"Hemdal.Notifier.html#module-implement-a-new-notifier"},{"type":"callback","title":"Hemdal.Notifier.attach/3","doc":"The attach callback which should return the map according to the information\nattached. The attachment is usually created with the accumulation of the fields\ninside.","ref":"Hemdal.Notifier.html#c:attach/3"},{"type":"callback","title":"Hemdal.Notifier.attach/4","doc":"Same as `attach/3` but let specify the `img_url` field for adding a custom\nimage to the message.","ref":"Hemdal.Notifier.html#c:attach/4"},{"type":"type","title":"Hemdal.Notifier.attach_color/0","doc":"The color provided for the attachment. The color is provided usually in\nthe format `#rrggbb` where we are providing a value from 00-ff for each\ncolor to create the RGB (red, green, and blue) combination.","ref":"Hemdal.Notifier.html#t:attach_color/0"},{"type":"type","title":"Hemdal.Notifier.attach_fields/0","doc":"The list of the fields attached.","ref":"Hemdal.Notifier.html#t:attach_fields/0"},{"type":"type","title":"Hemdal.Notifier.attach_name/0","doc":"The name of the attachment.","ref":"Hemdal.Notifier.html#t:attach_name/0"},{"type":"type","title":"Hemdal.Notifier.duration/0","doc":"The duration from previous status to the new one.","ref":"Hemdal.Notifier.html#t:duration/0"},{"type":"type","title":"Hemdal.Notifier.field/0","doc":"The field map representation of the field. It will be dependent of the\nnotifier backend which should determine what's the format desired for\nthe field.","ref":"Hemdal.Notifier.html#t:field/0"},{"type":"callback","title":"Hemdal.Notifier.field/2","doc":"Creates a field representation in a map. See `field/0` type for further\ninformation. It provides a field name and value which will be included\ninside of the field map returned. The return format finally will be\ndetermined by the implementation.","ref":"Hemdal.Notifier.html#c:field/2"},{"type":"callback","title":"Hemdal.Notifier.field/3","doc":"Creates a field representation in a map. See `field/0` type for further\ninformation. In addition to the field name and value it's receiving if\nthe field is short or not. It's put in this way to place two fields in\nthe same line (horizontally) if both are short.","ref":"Hemdal.Notifier.html#c:field/3"},{"type":"type","title":"Hemdal.Notifier.field_name/0","doc":"The field name is the name of the field which we provide from the sending\nof the message. We have defined the name of the fields and they are:\n\n- Host Name, based on the alert host name\n- Command Name, based on the alert command name\n- Description, description from metadata if any\n- Status, the new state\n- Prev. Status, the previous state\n- Duration, the duration from previous to current state\n- Incoming Status, the received status from the check","ref":"Hemdal.Notifier.html#t:field_name/0"},{"type":"type","title":"Hemdal.Notifier.field_value/0","doc":"The field value is the content which should be shown as the value. It must\nbe a string because finally all of the data will be represented as text.","ref":"Hemdal.Notifier.html#t:field_value/0"},{"type":"type","title":"Hemdal.Notifier.img_url/0","doc":"The URL for a custom image to be included inside of the attachment.","ref":"Hemdal.Notifier.html#t:img_url/0"},{"type":"type","title":"Hemdal.Notifier.message/0","doc":"The message is a data map where we can define different keys. The\ninformation (defined in `send/6`) is as follows:\n\n- `text` the text message to be sent\n- `username` provided by the notifier data, default: \"Hemdal\"\n- `icon_emoji` provided by the notifier metadata information,\n  default: \":rotating_light:\"\n- `channel` provided by the notifier metadata, default: \"#alerts\"\n- `attachments` is a list of attachments provided by the\n  `attach/3` callback implemented in the notifier.","ref":"Hemdal.Notifier.html#t:message/0"},{"type":"type","title":"Hemdal.Notifier.metadata/0","doc":"The metadata is provided by the notifier structure, see\n`Hemdal.Config.Notifier` for further information.","ref":"Hemdal.Notifier.html#t:metadata/0"},{"type":"callback","title":"Hemdal.Notifier.send/3","doc":"Callback for `send/3`. It must implement the necessary backend to send the\nmessage for the backend implementation. The information passed is the\nmessage formatted as a map, see `message/0` type for further information.\n\nThe token must be the information needed for the system to be authenticated\nor recognised to send the message.\n\nFinally, the metadata must be information to be used as extra information\ninside of the map to be useful for the backend. See `metadata/0` type for\nfurther information.","ref":"Hemdal.Notifier.html#c:send/3"},{"type":"function","title":"Hemdal.Notifier.send/6","doc":"Send the message using the notifier module, the status of the event,\nthe previous status, the alert information (see `Hemdal.Config.Alert`),\nmetadata and duration from the previous status to the current one.\n\nThe first parameter is the notifier data, see `Hemdal.Config.Notifier`\nfor further information.\n\nThe status could be an atom:\n\n- `:ok` for the success state\n- `:warn` when it's starting to fail\n- `:error` for the failure state\n- `:disabled` when the alert is disabled\n\nThe previous state could be `nil` if there is no previous state.\n\nThe metadata is a map which could contains the following keys as strings:\n\n- `\"message\"` for a description of the error, default: `\" \"`\n- `\"status\"` for the notification of the _Incoming Status_ or the status\n  which is provided from the alert.\n\nThe duration could be `nil` if there is no previous state or if from the\nprevious state was not expected to have a counting of the duration.","ref":"Hemdal.Notifier.html#send/6"},{"type":"type","title":"Hemdal.Notifier.short?/0","doc":"Is it a short field? It is determined mainly for Slack, Mattermost, and\nsimilar systems where we can include short fields in the way they could\nappear two fields in the same line if both are short.","ref":"Hemdal.Notifier.html#t:short?/0"},{"type":"type","title":"Hemdal.Notifier.status/0","doc":"The possible status processed by the messages.","ref":"Hemdal.Notifier.html#t:status/0"},{"type":"type","title":"Hemdal.Notifier.token/0","doc":"The token is provided from the notifier structure, see\n`Hemdal.Config.Notifier` for further information.","ref":"Hemdal.Notifier.html#t:token/0"},{"type":"module","title":"Hemdal.Notifier.Mattermost","doc":"Performs the notification from `Hemdal.Notifier` using Mattermost. It's\nusing the webhook capability of Slack to send the message to a specific\nchannel. You can see further information in this link:\n\nhttps://developers.mattermost.com/integrate/webhooks/incoming/","ref":"Hemdal.Notifier.Mattermost.html"},{"type":"function","title":"Hemdal.Notifier.Mattermost.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#delete/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#delete!/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#get/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#get!/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#head/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#head!/3"},{"type":"type","title":"Hemdal.Notifier.Mattermost.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"Hemdal.Notifier.Mattermost.html#t:option/0"},{"type":"function","title":"Hemdal.Notifier.Mattermost.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#options/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#options!/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Mattermost.html#patch/4"},{"type":"function","title":"Hemdal.Notifier.Mattermost.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Mattermost.html#patch!/4"},{"type":"function","title":"Hemdal.Notifier.Mattermost.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Mattermost.html#post/4"},{"type":"function","title":"Hemdal.Notifier.Mattermost.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Mattermost.html#post!/4"},{"type":"function","title":"Hemdal.Notifier.Mattermost.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Mattermost.html#put/4"},{"type":"function","title":"Hemdal.Notifier.Mattermost.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Mattermost.html#put!/4"},{"type":"function","title":"Hemdal.Notifier.Mattermost.request/2","doc":"Perform a request.","ref":"Hemdal.Notifier.Mattermost.html#request/2"},{"type":"function","title":"Options - Hemdal.Notifier.Mattermost.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyword list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"Hemdal.Notifier.Mattermost.html#request/2-options"},{"type":"function","title":"Examples - Hemdal.Notifier.Mattermost.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#request/2-examples"},{"type":"function","title":"Hemdal.Notifier.Mattermost.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"Hemdal.Notifier.Mattermost.html#request!/2"},{"type":"function","title":"Hemdal.Notifier.Mattermost.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#trace/3"},{"type":"function","title":"Hemdal.Notifier.Mattermost.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Mattermost.html#trace!/3"},{"type":"module","title":"Hemdal.Notifier.Mock","doc":"Let us perform tests using a notifier which we can control. It's working\ninjecting inside of the metadata the PID of the process where the\nnotification should be triggered.\n\nInside of the configuration we have to inject the notifier with the\ncorresponding information, it's important to choose a backend which let us\nuse the PID as data. If you see `Hemdal.CheckTest` you can find a way\nabout how to do this.","ref":"Hemdal.Notifier.Mock.html"},{"type":"module","title":"Hemdal.Notifier.Slack","doc":"Performs the notification from `Hemdal.Notifier` using Slack. It's using the\nwebhook capability of Slack to send the message to a specific channel. You\ncan see further information in this link:\n\nhttps://api.slack.com/messaging/webhooks","ref":"Hemdal.Notifier.Slack.html"},{"type":"function","title":"Hemdal.Notifier.Slack.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#delete/3"},{"type":"function","title":"Hemdal.Notifier.Slack.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#delete!/3"},{"type":"function","title":"Hemdal.Notifier.Slack.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#get/3"},{"type":"function","title":"Hemdal.Notifier.Slack.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#get!/3"},{"type":"function","title":"Hemdal.Notifier.Slack.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#head/3"},{"type":"function","title":"Hemdal.Notifier.Slack.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#head!/3"},{"type":"type","title":"Hemdal.Notifier.Slack.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"Hemdal.Notifier.Slack.html#t:option/0"},{"type":"function","title":"Hemdal.Notifier.Slack.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#options/3"},{"type":"function","title":"Hemdal.Notifier.Slack.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#options!/3"},{"type":"function","title":"Hemdal.Notifier.Slack.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Slack.html#patch/4"},{"type":"function","title":"Hemdal.Notifier.Slack.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Slack.html#patch!/4"},{"type":"function","title":"Hemdal.Notifier.Slack.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Slack.html#post/4"},{"type":"function","title":"Hemdal.Notifier.Slack.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Slack.html#post!/4"},{"type":"function","title":"Hemdal.Notifier.Slack.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Slack.html#put/4"},{"type":"function","title":"Hemdal.Notifier.Slack.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Hemdal.Notifier.Slack.html#put!/4"},{"type":"function","title":"Hemdal.Notifier.Slack.request/2","doc":"Perform a request.","ref":"Hemdal.Notifier.Slack.html#request/2"},{"type":"function","title":"Options - Hemdal.Notifier.Slack.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyword list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"Hemdal.Notifier.Slack.html#request/2-options"},{"type":"function","title":"Examples - Hemdal.Notifier.Slack.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#request/2-examples"},{"type":"function","title":"Hemdal.Notifier.Slack.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"Hemdal.Notifier.Slack.html#request!/2"},{"type":"function","title":"Hemdal.Notifier.Slack.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#trace/3"},{"type":"function","title":"Hemdal.Notifier.Slack.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Hemdal.Notifier.Slack.html#trace!/3"},{"type":"extras","title":"Getting started","doc":"# Getting started\n\nHemdal is a library designed to run commands and retrieve a result. It let us implement the different aspects of the system as we want and it's extensible enough to provide us ways of implementing extensions without modifying the core code base.\n\nHemdal isn't a stand-alone system, if you need that kind of service, check [Hemdal UI](https://github.com/altenwald/hemdal_ui) which implements Hemdal User Interface with [Phoenix Framework](https://phoenixframework.org) and [Trooper](https://github.com/army-cat/trooper) for providing more features and a stand-alone way to run Hemdal.","ref":"getting_started.html"},{"type":"extras","title":"Understanding the layers - Getting started","doc":"You need to understand the elements of Hemdal to know how to use it and extend it. The layers are:\n\n- `Hemdal.Host` is the way Hemdal connects with the hosts to run commands. It's an implementation of a pool of hosts defined by the maximum number of tasks that could be running at the same time on the same host.\n- `Hemdal.Check` is the state of each alarm/alert of the system. It's a state machine that is running in a defined interval of time a command against a host. Depending on the result it's generating information and changes its state.\n- `Hemdal.Event` is the event generator, each time the state machine (`Hemdal.Check`) generates an event, it goes to this module and it's sent to all of its consumers. It's based on `GenStage` and you can create as many consumers as you need.\n- `Hemdal.Notifier` is a specific consumer for `Hemdal.Event` which has the mission to report the events to specific endpoints. You can implement new modules to provide new ways of notification.\n\nThese are the basic ways we can provide for extending the system.","ref":"getting_started.html#understanding-the-layers"},{"type":"extras","title":"Hosts - Getting started","doc":"At the moment, to connect to different hosts, we provide only one way, but because SSH is a bit more complicated, we created a new repository to show you how to extend Hemdal in a non-intrusive way to implement your stuff:\n\n- `Hemdal.Host.Local` is running commands using `System.shell/2`, it's not too fancy but it's useful.\n- [`Hemdal.Host.Trooper`](https://github.com/altenwald/hemdal_trooper) is a way to implement SSH to connect to remote hosts.\n\nSee `Hemdal.Config.Host` to know how to configure and use them.","ref":"getting_started.html#hosts"},{"type":"extras","title":"Events - Getting started","doc":"While there are different examples that you can see in the source code, it's easier to think about the events as a simple `GenStage` consumer. You can write your own, put it under your supervisor and consume it from `Hemdal.Event`. You will receive always the `%Hemdal.Event{}` structure.\n\nWe have the implementation of the following event consumers:\n\n- `Hemdal.Event.Log` which is triggering a log for each event received.\n- `Hemdal.Event.Notification` which is converting the event into a notification for the notifier.\n- `Hemdal.Event.Mock` which is in use for test purposes.","ref":"getting_started.html#events"},{"type":"extras","title":"Notifiers - Getting started","doc":"The notifiers are defined in the alert configuration (see `Hemdal.Config.Alert`). You can specify a list of notifiers to be in use every time a new event is triggering a notification.\n\nWe have defined the following notifiers:\n\n- `Hemdal.Notifier.Slack` which is triggering a message for the Slack system.\n- `Hemdal.Notifier.Mattermost` which is triggering a message for the Mattermost system.\n- `Hemdal.Notifier.Mock` which is for testing purposes.","ref":"getting_started.html#notifiers"},{"type":"extras","title":"Creating Alerts","doc":"# Creating Alerts\n\nTBD","ref":"creating_alerts.html"},{"type":"extras","title":"Notifying to Slack","doc":"# Notifying to Slack\n\nTBD","ref":"notifying_to_slack.html"}],"proglang":"elixir","producer":{"name":"ex_doc","version":"0.37.3"},"content_type":"text/markdown"}